@@ -76,8 +76,6 @@ enum
 
 
 
-static void       xfwm_settings_class_init                           (XfwmSettingsClass    *klass);
-static void       xfwm_settings_init                                 (XfwmSettings         *settings);
 static void       xfwm_settings_constructed                          (GObject              *object);
 static void       xfwm_settings_finalize                             (GObject              *object);
 static void       xfwm_settings_get_property                         (GObject              *object,
@@ -198,6 +196,8 @@ struct _XfwmSettingsPrivate
   XfconfChannel         *wm_channel;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (XfwmSettings, xfwm_settings, G_TYPE_OBJECT)
+
 struct _MenuTemplate
 {
   const gchar *name;
@@ -212,14 +212,12 @@ enum
 };
 
 
-
-G_DEFINE_TYPE_WITH_PRIVATE (XfwmSettings, xfwm_settings, G_TYPE_OBJECT)
-
 static const MenuTemplate double_click_values[] = {
   { N_("Shade window"), "shade" },
   { N_("Hide window"), "hide" },
   { N_("Maximize window"), "maximize" },
   { N_("Fill window"), "fill" },
+  { N_("Always on top"), "above" },
   { N_("Nothing"), "none" },
   { NULL, NULL }
 };
@@ -511,8 +509,7 @@ xfwm_settings_constructed (GObject *object)
     gtk_tree_view_insert_column (GTK_TREE_VIEW (shortcuts_treeview), column, 1);
     gtk_tree_view_column_set_sort_column_id (column, SHORTCUTS_SHORTCUT_LABEL_COLUMN);
 
-    // set initial sorting
-    gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (list_store), SHORTCUTS_NAME_COLUMN, GTK_SORT_ASCENDING);
+    /* Initial sorting: By category; given by the model */
 
     g_signal_connect (shortcuts_treeview, "row-activated",
                       G_CALLBACK (xfwm_settings_shortcut_row_activated), settings);
