@@ -82,43 +82,41 @@
 #define MAIN_EVENT_MASK BASE_EVENT_MASK
 #endif /* HAVE_COMPOSITOR */
 
-enum {
-    COMPOSITOR_MODE_OFF = 0,
-    COMPOSITOR_MODE_AUTO,
-    COMPOSITOR_MODE_MANUAL
-};
-
-static gint compositor = COMPOSITOR_MODE_MANUAL;
+#ifdef HAVE_COMPOSITOR
+static gboolean compositor = TRUE;
 static vblankMode vblank_mode = VBLANK_AUTO;
 #define XFWM4_ERROR      (xfwm4_error_quark ())
 
-#ifndef DEBUG
-/* For what, IEEE Std 1003.1-2001, Section 12.2, Utility Syntax Guidelines.*/
-static char revision[]="@(#)$ " PACKAGE " version " VERSION " revision " REVISION " $";
-#endif
-
 static GQuark
 xfwm4_error_quark (void)
 {
   return g_quark_from_static_string ("xfwm4-error-quark");
 }
+#endif /* HAVE_COMPOSITOR */
 
 #ifdef DEBUG
 static gboolean
-setupLog (void)
+setupLog (gboolean debug)
 {
     const gchar *str;
     gchar *logfile;
     int fd;
 
-    str = g_getenv ("XFWM4_LOG_FILE");
-    if (str)
+    if (debug)
     {
-        logfile = g_strdup (str);
+        str = g_getenv ("XFWM4_LOG_FILE");
+        if (str)
+        {
+            logfile = g_strdup (str);
+        }
+        else
+        {
+            logfile = g_strdup_printf ("xfwm4-debug-%d.log", (int) getpid ());
+        }
     }
     else
     {
-        logfile = g_strdup_printf ("xfwm4-debug-%d.log", (int) getpid ());
+        logfile = "/dev/null";
     }
 
     fd = dup(fileno(stderr));
@@ -137,8 +135,11 @@ setupLog (void)
         return FALSE;
     }
 
-    g_print ("Logging to %s\n", logfile);
-    g_free (logfile);
+    if (debug)
+    {
+        g_print ("Logging to %s\n", logfile);
+        g_free (logfile);
+    }
 
     return TRUE;
 }
@@ -414,31 +415,6 @@ print_version (void)
 #endif
 }
 
-#ifdef HAVE_COMPOSITOR
-static gint
-get_default_compositor (DisplayInfo *display_info)
-{
-    /*
-     * Don't even check for the render speed if there is no compositor.
-     */
-    if (!display_info->enable_compositor)
-    {
-        return 0;
-    }
-
-    /*
-     * Check if the XServer is black listed.
-     */
-    if (!compositorTestServer (display_info))
-    {
-        g_warning ("The XServer currently in use on this system is not suitable for the compositor");
-        return 0;
-    }
-
-    return 2;
-}
-#endif /* HAVE_COMPOSITOR */
-
 #ifdef HAVE_COMPOSITOR
 static gboolean
 compositor_callback (const gchar  *name,
@@ -452,15 +428,11 @@ compositor_callback (const gchar  *name,
 
     if (strcmp (value, "off") == 0)
     {
-        compositor = COMPOSITOR_MODE_OFF;
-    }
-    else if (strcmp (value, "auto") == 0)
-    {
-        compositor = COMPOSITOR_MODE_AUTO;
+        compositor = FALSE;
     }
     else if (strcmp (value, "on") == 0)
     {
-        compositor = COMPOSITOR_MODE_MANUAL;
+        compositor = TRUE;
     }
     else
     {
@@ -508,27 +480,8 @@ vblank_callback (const gchar  *name,
     return succeed;
 }
 
-static gint
-init_compositor_display (DisplayInfo *display_info, gint compositor_mode)
-{
-    if (compositor_mode < COMPOSITOR_MODE_OFF)
-    {
-        compositor_mode = get_default_compositor (display_info);
-    }
-
-    /* Disabling compositor from command line */
-    if (!compositor_mode)
-    {
-        display_info->enable_compositor = FALSE;
-    }
-    compositorSetCompositeMode (display_info,
-                                (compositor_mode == COMPOSITOR_MODE_MANUAL));
-
-    return compositor_mode;
-}
-
 static void
-init_compositor_screen (ScreenInfo *screen_info, gint compositor_mode)
+init_compositor_screen (ScreenInfo *screen_info)
 {
     DisplayInfo *display_info;
 
@@ -538,11 +491,7 @@ init_compositor_screen (ScreenInfo *screen_info, gint compositor_mode)
         compositorSetVblankMode (screen_info, vblank_mode);
     }
 
-    if (compositor_mode == COMPOSITOR_MODE_AUTO)
-    {
-        compositorManageScreen (screen_info);
-    }
-    else if (compositor_mode == COMPOSITOR_MODE_MANUAL)
+    if (display_info->enable_compositor)
     {
         gboolean xfwm4_compositor;
 
@@ -572,7 +521,7 @@ init_compositor_screen (ScreenInfo *screen_info, gint compositor_mode)
 #endif /* HAVE_COMPOSITOR */
 
 static int
-initialize (gint compositor_mode, gboolean replace_wm)
+initialize (gboolean replace_wm)
 {
     DisplayInfo *display_info;
     gint i, nscreens, default_screen;
@@ -587,12 +536,8 @@ initialize (gint compositor_mode, gboolean replace_wm)
     display_info = myDisplayInit (gdk_display_get_default ());
 
 #ifdef HAVE_COMPOSITOR
-    if (display_info->enable_compositor)
-    {
-        compositor_mode =
-            init_compositor_display (display_info, compositor_mode);
-    }
-#else /* HAVE_COMPOSITOR */
+    display_info->enable_compositor = compositor;
+#else
     display_info->enable_compositor = FALSE;
 #endif /* HAVE_COMPOSITOR */
 
@@ -651,7 +596,7 @@ initialize (gint compositor_mode, gboolean replace_wm)
 #ifdef HAVE_COMPOSITOR
         if (display_info->enable_compositor)
         {
-            init_compositor_screen (screen_info, compositor_mode);
+            init_compositor_screen (screen_info);
         }
 #endif /* HAVE_COMPOSITOR */
         sn_init_display (screen_info);
@@ -711,16 +656,15 @@ main (int argc, char **argv)
     int status;
     GOptionContext *context;
     GError *error = NULL;
-
-#ifndef HAVE_COMPOSITOR
-    gchar *compositor_foo = NULL;
-#endif
+#ifdef DEBUG
+    gboolean debug = FALSE;
+#endif /* DEBUG */
     GOptionEntry option_entries[] =
     {
 #ifdef HAVE_COMPOSITOR
-        { "compositor", '\0', 0, G_OPTION_ARG_CALLBACK,
-          compositor_callback, N_("Set the compositor mode"), "on|off|auto" },
-        { "vblank", '\0', 0, G_OPTION_ARG_CALLBACK,
+        { "compositor", 'c', 0, G_OPTION_ARG_CALLBACK,
+          compositor_callback, N_("Set the compositor mode"), "on|off" },
+        { "vblank", 'b', 0, G_OPTION_ARG_CALLBACK,
           vblank_callback, N_("Set the vblank mode"), "off"
 #ifdef HAVE_PRESENT_EXTENSION
           "|xpresent"
@@ -730,18 +674,17 @@ main (int argc, char **argv)
 #endif /* HAVE_EPOXY */
         },
 #endif /* HAVE_COMPOSITOR */
-        { "replace", '\0', 0, G_OPTION_ARG_NONE,
+        { "replace", 'r', 0, G_OPTION_ARG_NONE,
           &replace_wm, N_("Replace the existing window manager"), NULL },
         { "version", 'V', 0, G_OPTION_ARG_NONE,
           &version, N_("Print version information and exit"), NULL },
+#ifdef DEBUG
+        { "debug", 'd', 0, G_OPTION_ARG_NONE,
+          &debug, N_("Enable debug logging"), NULL },
+#endif /* DEBUG */
         { NULL }
     };
 
-#ifdef DEBUG
-    setupLog ();
-#endif /* DEBUG */
-    DBG ("xfwm4 starting");
-
 #ifdef HAVE_EPOXY
     /* NVIDIA proprietary/closed source driver queues up to 2 frames by
      * default before blocking in glXSwapBuffers(), whereas our compositor
@@ -792,6 +735,11 @@ main (int argc, char **argv)
     }
     g_option_context_free (context);
 
+#ifdef DEBUG
+    setupLog (debug);
+#endif /* DEBUG */
+    DBG ("xfwm4 starting");
+
     gtk_init (&argc, &argv);
 
     if (G_UNLIKELY (version))
@@ -801,7 +749,7 @@ main (int argc, char **argv)
     }
     init_pango_cache ();
 
-    status = initialize (compositor, replace_wm);
+    status = initialize (replace_wm);
     /*
        status  < 0   =>   Error, cancel execution
        status == 0   =>   Run w/out session manager
