@@ -112,6 +112,7 @@ poswinSetPosition (Poswin * poswin, Client *c)
     gchar label[32];
     gint x, y, px, py, pw, ph;
     gint wsize, hsize;
+    gint scale;
 
     g_return_if_fail (poswin != NULL);
     g_return_if_fail (c != NULL);
@@ -141,8 +142,9 @@ poswinSetPosition (Poswin * poswin, Client *c)
     gtk_label_set_text (GTK_LABEL (poswin->label), label);
     gtk_widget_queue_draw (GTK_WIDGET(poswin));
     gtk_window_get_size (GTK_WINDOW (poswin), &pw, &ph);
-    px = x + (frameWidth (c) - pw) / 2;
-    py = y + (frameHeight (c) - ph) / 2;
+    scale = gdk_window_get_scale_factor (myScreenGetGdkWindow (c->screen_info));
+    px = (x + (frameWidth (c) - pw * scale) / 2) / scale;
+    py = (y + (frameHeight (c) - ph * scale) / 2) / scale;
     gtk_window_move (GTK_WINDOW (poswin), px, py);
 }
 
