@@ -197,12 +197,14 @@ struct _ScreenInfo
     guchar *shadowTop;
 
     gushort current_buffer;
+    gushort use_n_buffers;
     Pixmap rootPixmap[N_BUFFERS];
     Picture rootBuffer[N_BUFFERS];
     Picture zoomBuffer;
     Picture rootPicture;
     Picture blackPicture;
     Picture rootTile;
+    XserverRegion screenRegion;
     XserverRegion prevDamage;
     XserverRegion allDamage;
     unsigned long cursorSerial;
@@ -230,16 +232,20 @@ struct _ScreenInfo
 
 #ifdef HAVE_EPOXY
     gboolean texture_inverted;
+    gboolean has_mesa_swap_control;
+    gboolean has_ext_swap_control;
+    gboolean has_ext_arb_sync;
 
     GLuint rootTexture;
     GLenum texture_format;
     GLenum texture_target;
     GLenum texture_type;
     GLfloat texture_filter;
-    GLXDrawable glx_drawable;
+    GLXDrawable glx_drawable[N_BUFFERS];
     GLXFBConfig glx_fbconfig;
     GLXContext glx_context;
     GLXWindow glx_window;
+    GLsync gl_sync;
 #ifdef HAVE_XSYNC
     XSyncFence fence[N_BUFFERS];
 #endif /* HAVE_XSYNC */
