@@ -677,6 +677,7 @@ loadSettings (ScreenInfo *screen_info)
         {"cycle_raise", NULL, G_TYPE_BOOLEAN, TRUE},
         {"cycle_hidden", NULL, G_TYPE_BOOLEAN, TRUE},
         {"cycle_minimum", NULL, G_TYPE_BOOLEAN, TRUE},
+        {"cycle_minimized", NULL, G_TYPE_BOOLEAN, TRUE},
         {"cycle_preview", NULL, G_TYPE_BOOLEAN, TRUE},
         {"cycle_tabwin_mode", NULL, G_TYPE_INT, FALSE},
         {"cycle_workspaces", NULL, G_TYPE_BOOLEAN, TRUE},
@@ -772,6 +773,8 @@ loadSettings (ScreenInfo *screen_info)
         getBoolValue ("cycle_apps_only", rc);
     screen_info->params->cycle_minimum =
         getBoolValue ("cycle_minimum", rc);
+    screen_info->params->cycle_minimized =
+        getBoolValue ("cycle_minimized", rc);
     screen_info->params->cycle_draw_frame =
         getBoolValue ("cycle_draw_frame", rc);
     screen_info->params->cycle_raise =
@@ -894,6 +897,10 @@ loadSettings (ScreenInfo *screen_info)
     {
         screen_info->params->double_click_action = DOUBLE_CLICK_ACTION_FILL;
     }
+    else if (!g_ascii_strcasecmp ("above", value))
+    {
+        screen_info->params->double_click_action = DOUBLE_CLICK_ACTION_ABOVE;
+    }
     else
     {
         screen_info->params->double_click_action = DOUBLE_CLICK_ACTION_NONE;
@@ -1325,6 +1332,10 @@ cb_xfwm4_channel_property_changed(XfconfChannel *channel, const gchar *property_
                 {
                     screen_info->params->cycle_minimum = g_value_get_boolean (value);
                 }
+                else if (!strcmp (name, "cycle_minimized"))
+                {
+                    screen_info->params->cycle_minimized = g_value_get_boolean (value);
+                }
                 else if (!strcmp (name, "cycle_draw_frame"))
                 {
                     screen_info->params->cycle_draw_frame = g_value_get_boolean (value);
@@ -1447,7 +1458,7 @@ cb_xfwm4_channel_property_changed(XfconfChannel *channel, const gchar *property_
 static gboolean
 keymap_reload (gpointer data)
 {
-    ScreenInfo *screen_info = (ScreenInfo *) data;
+    ScreenInfo *screen_info = data;
 
     g_return_val_if_fail (screen_info != NULL, FALSE);
     TRACE ("entering");
@@ -1481,8 +1492,8 @@ cb_keys_changed (GdkKeymap *keymap, ScreenInfo *screen_info)
     }
     keymap_timeout = g_timeout_add_full (G_PRIORITY_DEFAULT,
                                          KEYMAP_UPDATE_TIMEOUT,
-                                         (GSourceFunc) keymap_reload,
-                                         (gpointer) screen_info, NULL);
+                                         keymap_reload,
+                                         screen_info, NULL);
 }
 
 static void
