@@ -52,7 +52,7 @@ static SnDisplay *sn_display = NULL;
 typedef struct
 {
     GSList *list;
-    GTimeVal now;
+    gint64 now;
 }
 CollectTimedOutData;
 
@@ -139,9 +139,8 @@ sn_collect_timed_out_foreach (void *element, void *data)
     sn_startup_sequence_get_last_active_time (sequence, &l_sec, &l_usec);
     tv_sec = l_sec; tv_usec = l_sec;
 
-    elapsed =
-        ((((double) ctod->now.tv_sec - tv_sec) * G_USEC_PER_SEC +
-            (ctod->now.tv_usec - tv_usec))) / 1000.0;
+    elapsed = ((double) ctod->now - (tv_sec * G_USEC_PER_SEC) - tv_usec)
+        / 1000.0;
 
     if (elapsed > STARTUP_TIMEOUT)
     {
@@ -160,7 +159,7 @@ sn_startup_sequence_timeout (void *data)
     g_return_val_if_fail (screen_info != NULL, FALSE);
 
     ctod.list = NULL;
-    g_get_current_time (&ctod.now);
+    ctod.now = g_get_real_time ();
     g_slist_foreach (screen_info->startup_sequences, sn_collect_timed_out_foreach, &ctod);
 
     tmp = ctod.list;
